PCB Environment: ActionSpace Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Protected Attributes
ActionSpace Class Reference

## Public Member Functions
virtual void | clear (bool deleteActions)
uint | size () const
const std::vector< Action * > & | actions () const
Action * | getAction (Action::Index a) const
Action * | getAction (const std::string &name) const
Action * | getAction (PyObject *) const
void | addAction (Action *)
void | setOwnsActions (bool own)
bool | ownsActions () const
const std::set< Action::Index > & | getIllegal () const
void | setLegal (Action *, bool)
PyObject * | getPy () const

## Protected Attributes
std::vector< Action * > | mActions

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RL/ActionSpace.hpp